# ANTConnect

Provides access to an ANT CDE
For more details, visit [docs.antcde.io](https://docs.antcde.io/)

## Release notes

### Version 2021.05.1
- Updates Tasks API Calls and includes download files

### Version 2021.04
- Adds Tasks API calls to the SDK

### Version 2020.20.5
- Adds multiple options in column create and column update

### Version 2020.20.2
- Complements update of API on ANTCDE

### Version 2020.18.1
- Added more consistancy

### Version 0.1.3
- Bugfix

### Version 0.1.2
- Bugfix Column Create

### Version 0.1.0
- Initial version